@@ -12,6 +12,8 @@
 #include <vector>
 #include <memory>
 
+constexpr auto TESTED_YTMUSICAPI_VERSION = "1.1.0";
+
 struct YTMusicPrivate;
 
 namespace meta {
@@ -54,14 +56,14 @@ struct Video : public Media {
 struct Playlist {
     std::string browse_id;
     std::string title;
-    std::string author;
+    std::optional<std::string> author;
     std::string item_count;
     std::vector<meta::Thumbnail> thumbnails;
 };
 
 struct Song : public Media {
     std::optional<meta::Album> album;
-    bool is_explicit;
+    std::optional<bool> is_explicit;
 };
 
 struct Album {
@@ -82,7 +84,16 @@ struct Artist {
     std::vector<meta::Thumbnail> thumbnails;
 };
 
-using SearchResultItem = std::variant<Video, Playlist, Song, Album, Artist>;
+struct TopResult {
+    std::string category;
+    std::string result_type;
+    std::optional<std::string> video_id;
+    std::optional<std::string> title;
+    std::vector<meta::Artist> artists;
+    std::vector<meta::Thumbnail> thumbnails;
+};
+
+using SearchResultItem = std::variant<Video, Playlist, Song, Album, Artist, TopResult>;
 };
 
 
@@ -147,7 +158,7 @@ struct Artist {
 
 namespace album {
     struct Track {
-        bool is_explicit;
+        std::optional<bool> is_explicit;
         std::string title;
         std::vector<meta::Artist> artists;
         std::optional<std::string> album;
@@ -184,25 +195,16 @@ struct Song {
     std::string video_id;
     std::string title;
     std::string length;
-    std::vector<std::string> keywords;
     std::string channel_id;
     bool is_owner_viewer;
-    std::string short_description;
     bool is_crawlable;
     Thumbnail thumbnail;
-    float average_rating;
-    bool allow_ratings;
     std::string view_count;
     std::string author;
     bool is_private;
     bool is_unplugged_corpus;
     bool is_live_content;
-    std::string provider;
     std::vector<std::string> artists;
-    std::string copyright;
-    std::vector<std::string> production;
-    std::string release;
-    std::string category;
 };
 }
 
@@ -212,11 +214,11 @@ struct Track {
     std::string title;
     std::vector<meta::Artist> artists;
     std::optional<meta::Album> album;
-    std::string duration;
+    std::optional<std::string> duration;
     std::optional<std::string> like_status;
     std::vector<meta::Thumbnail> thumbnails;
     bool is_available;
-    bool is_explicit;
+    std::optional<bool> is_explicit;
 };
 
 struct Playlist {
@@ -225,7 +227,7 @@ struct Playlist {
     std::string title;
     std::vector<meta::Thumbnail> thumbnails;
     meta::Artist author;
-    std::string year;
+    std::optional<std::string> year;
     std::string duration;
     int track_count;
     std::vector<Track> tracks;
@@ -304,7 +306,7 @@ public:
     std::optional<song::Song> get_song(const std::string &video_id) const;
 
     /// https://ytmusicapi.readthedocs.io/en/latest/reference.html#ytmusicapi.YTMusic.get_playlist
-    playlist::Playlist get_playlist(const std::string &playlist_id, int limit = 100) const;
+    playlist::Playlist get_playlist(const std::string &playlist_id, int limit = 1024) const;
 
     /// https://ytmusicapi.readthedocs.io/en/latest/reference.html#ytmusicapi.YTMusic.get_artist_albums
     std::vector<artist::Artist::Album> get_artist_albums(const std::string &channel_id, const std::string &params) const;
